pub enum ItemType {
Default,
File,
FileSkipCheck,
}Expand description
Item types
Variants
Default
Default type for an item.
File
Type representing a file.
Alredy checks that the file exists on disk, and hides the result if it does not.
FileSkipCheck
Type representing a file, with filesystem checks skipped.
Similar to File but skips the check to ensure the file exists.